@@ -8,9 +8,54 @@ from .orm import get_base
 Base = get_base()
 
 
+class BrandConfig(Base):
+    """
+    Неизвестная модель
+    """
+    __tablename__ = 'brand_configs'
+
+    # MD5-хеш
+    md5 = Column(String(32), primary_key=True)
+
+    # Переменные
+    # YAML-формат
+    variables = Column(String)
+
+    # Неизвестное поле
+    share = Column(Boolean)
+
+    # Наименование
+    name = Column(String(255))
+
+    # Дата и время создания
+    # server_default - Автоматически устанавливает значение created_at на текущую дату и время при создании
+    created_at = Column(DateTime, server_default=func.now())
+
+    # Неизвестное поле
+    js_overrides = Column(String)
+
+    # Неизвестное поле
+    css_overrides = Column(String)
+
+    # Неизвестное поле
+    mobile_js_overrides = Column(String)
+
+    # Неизвестное поле
+    mobile_css_overrides = Column(String)
+
+    # Неизвестное поле
+    parent_md5 = Column(String(255))
+
+    def __repr__(self):
+        return f'<BrandConfig {self} (md5={self.md5})>'
+
+    def __str__(self):
+        return f'{self.name}'
+
+
 class Account(Base):
     """
-    Модель "Учетная запись"
+    Учетная запись
     """
     __tablename__ = 'accounts'
 
@@ -18,7 +63,154 @@ class Account(Base):
     id = Column(Integer, primary_key=True)
 
     # Наименование
-    name = Column(String)
+    name = Column(String(255))
+
+    # Дата и время создания
+    # server_default - Автоматически устанавливает значение created_at на текущую дату и время при создании
+    created_at = Column(DateTime, server_default=func.now())
+
+    # Дата и время изменения
+    # onupdate - Автоматически изменяет updated_at на текущую дату и время
+    updated_at = Column(DateTime, onupdate=func.now())
+
+    # Статус
+    # Возможные значения:
+    # - active (Активный)
+    # - deleted (Удаленный)
+    workflow_state = Column(String(255), default='active')
+
+    @validates('workflow_state')
+    def validate_workflow_state(self, key, value):
+        """
+        Значением workflow_state могут быть следующие значения:
+        - active (Активный)
+        - deleted (Удаленный)
+        """
+        assert value in ['active', 'deleted']
+        return value
+
+    # Дата и время удаления
+    # deleted_at необходимо ставить когда workflow_state='deleted'
+    deleted_at = Column(DateTime)
+
+    @validates('deleted_at')
+    def validate_deleted_at(self, key, value):
+        """
+        deleted_at необходимо ставить когда workflow_state='deleted'
+        """
+        if self.workflow_state == 'deleted':
+            assert value is not None
+
+        return value
+
+    # Родительская учетная запись
+    parent_account_id = Column(ForeignKey('accounts.id'))
+    parent_account = relationship('Account')
+
+    # SIS-идентификатор
+    sis_source_id = Column(String(255))
+
+    # Неизвестное поле
+    sis_batch_id = Column(Integer)
+
+    # Неизвестное поле
+    current_sis_batch_id = Column(Integer)
+
+    # Корневая учетная запись
+    root_account_id = Column(ForeignKey('accounts.id'))
+    root_account = relationship('Account')
+
+    # Неизвестное поле
+    last_successful_sis_batch_id = Column(Integer)
+
+    # Неизвестное поле
+    membership_types = Column(String(255))
+
+    # Временная зона по-умолчанию
+    default_time_zone = Column(String(255))
+
+    # Неизвестное поле
+    external_status = Column(String(255))
+
+    # Неизвестное поле
+    storage_quota = Column(Integer)
+
+    # Неизвестное поле
+    default_storage_quota = Column(Integer)
+
+    # Неизвестное поле
+    enable_user_notes = Column(Boolean)
+
+    # Неизвестное поле
+    allowed_services = Column(String(255))
+
+    # Неизвестное поле
+    turnitin_pledge = Column(String)
+
+    # Неизвестное поле
+    turnitin_comments = Column(String)
+
+    # Неизвестное поле
+    turnitin_account_id = Column(String(255))
+
+    # Неизвестное поле
+    turnitin_salt = Column(String(255))
+
+    # Неизвестное поле
+    turnitin_crypted_secret = Column(String(255))
+
+    # Неизвестное поле
+    show_section_name_as_course_name = Column(Boolean)
+
+    # Неизвестное поле
+    allow_sis_import = Column(Boolean)
+
+    # Неизвестное поле
+    equella_endpoint = Column(String(255))
+
+    # Настройки
+    # YAML-формат
+    settings = Column(String)
+
+    # UUID-идентификатор
+    uuid = Column(String(255))
+
+    # Язык по-умолчанию
+    default_locale = Column(String(255))
+
+    # Неизвестное поле
+    stuck_sis_fields = Column(String)
+
+    # Неизвестное поле
+    default_user_storage_quota = Column(Integer)
+
+    # LTI-идентификатор
+    lti_guid = Column(String(255))
+
+    # Неизвестное поле
+    default_group_storage_quota = Column(Integer)
+
+    # Неизвестное поле
+    turnitin_host = Column(String(255))
+
+    # Неизвестное поле
+    integration_id = Column(String(255))
+
+    # Неизвестное поле
+    lti_context_id = Column(String(255))
+
+    # Неизвестный модель (BrandConfig)
+    brand_config_md5 = Column(ForeignKey('brand_configs.md5'))
+    brand_config = relationship('BrandConfig')
+
+    # Неизвестное поле
+    turnitin_originality = Column(String(255))
+
+    # Неизвестное поле
+    latest_outcome_import_id = Column(Integer)
+
+    # Неизвестное поле
+    course_template_id = Column(Integer)
 
     def __repr__(self):
         return '<Account {} (id={})>'.format(self, self.id)
